
# This file was generated by 'versioneer.py' (0.17) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2018-04-06T12:58:13-0400",
 "dirty": false,
 "error": null,
 "full-revisionid": "07b3840d1065df1d2ebebf67d1f0a9a33eb9c28e",
 "version": "1.21.6"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
